@@ -9,8 +9,9 @@ from LibWiser.must import *
 import LibWiser.FermiSource as FermiSource
 import LibWiser.WiserImport as lw
 import LibWiser.Optics as Optics
-from LibWiser.Foundation import OpticalElement
-import LibWiser.Enums as Enums
+from LibWiser.Foundation import OpticalElement, BeamlineElements
+from LibWiser.Enums import OPTICS_ORIENTATION
+
 from LibWiser.Exceptions import WiserException
 
 from LibWiser.ToolLib import CommonPlots
@@ -19,6 +20,7 @@ SmartPlot = CommonPlots.SmartPlot
 from time import time
 from LibWiser.Scrubs import UpdateDictionary
 
+import LibWiser.Enums as Enums
 HORIZONTAL = Enums.OPTICS_ORIENTATION.HORIZONTAL
 VERTICAL = Enums.OPTICS_ORIENTATION.VERTICAL
 ANY = Enums.OPTICS_ORIENTATION.ANY
